function [Xrange,Yrange] = def_oblast(L)
% DEF_OBLAST Definira oblast okolu zazemjuvacot vrz osnova na minimalnite i
%            maksimalnite koordinati vo matricata L.
%
%   [Xrange,Yrange] = def_oblast(L)
%
%   Vlez:
%       L  : Matrica so podatoci za sprovodnicite. Vo prvite 6 koloni se
%            dadeni x, y i z koordinatite na krajnite tocki od sekoj
%            sprovodnik (izrazeni vo m), a vo kolonata 7 e dijametarot na
%            sprovodnikot (izrazen vo mm).
%
%   Izlez:
%     Xrange : Opseg na vrednosti za x koordinati vo format -10:0.2:10 so
%              koi se definira oblasta okolu zazemjuvacot.
%     Yrange : Opseg na vrednosti za y koordinati vo format -10:0.2:10 so
%              koi se definira oblasta okolu zazemjuvacot.
%
%  See also ZAZEM, POTENCIJAL_INKA.

[x,y] = deal(L(:,[1 4]),L(:,[2 5]));
xmin = min(x(:)); xmax = max(x(:)); dx = xmax-xmin;
x1 = xmin-dx/2; x2 = xmax+dx/2;
ymin = min(y(:)); ymax = max(y(:)); dy = ymax - ymin;
y1 = ymin-dy/2; y2 = ymax+dy/2;
if x1 == 0 && x2 == 0
    x1 = y1;
    x2 = y2;
end
if y1 == 0 && y2 == 0
    y1 = x1;
    y2 = x2;
end
Xrange = x1:0.5:x2;
Yrange = y1:0.5:y2;
