function [X,Y,fi] = potencijal_inka(datoteka,Xrange,Yrange)
% POTENCIJAL_INKA Crtanje na potencijalnata inka okolu zazemjuvacot.
%
%   [X,Y,fi] = potencijal_inka(datoteka,Xrange,Yrange)
%
%   Vlez:
%    datoteka : Ime na datotekata vo koja se dadeni podatocite za
%               zazemjuvacot. Detali za nejzina sodrzina moze da se vidat
%               vo zazemformat.
%      Xrange : Opseg na vrednosti za x koordinati vo format -10:0.2:10 so
%               koi se definira oblasta za presmetuvanje na potencijalite.
%               Ako promenlivata Xrange ne se zadade togas taa ke bide
%               odredena so funkcijata def_oblast.
%      Yrange : Opseg na vrednosti za y koordinati.
%               Ako promenlivata Yrange ne se zadade se zema Yrange=Xrange.
%
%   Izlez:
%       X : Oblast na promena na koordinatite po x oska.
%       Y : Oblast na promena na koordinatite po y oska.
%      fi : Vrednost na presmetaniot potencijal.
%
%  See also ZAZEM.

[R,Rz,Uz,I,L,E,Z] = zazem(datoteka,0);
switch nargin
    case 1
        [Xrange,Yrange] = def_oblast(L);
    case 2
        Yrange = Xrange;
end
[X,Y] = meshgrid(Xrange,Yrange);
[m, n] = size(X);
fi = zeros(m,n);
for i = 1:m
    for j = 1:n
        fi(i,j) = 2*potencijal_tocka([X(i,j) Y(i,j) 0],I,L,Z.rho)/Uz*100;
    end
end
% crtanje na potencijalnata inka za fi
% http://stackoverflow.com/questions/11615921/matlab-surface-plot-not-working
figure
% set(gcf(), 'Renderer', 'painters');
set(gcf(), 'Renderer', 'zbuffer');
% set(gcf(), 'Renderer', 'OpenGL');
surf(X,Y,fi)
% colormap(autumn)
xlabel('X(m)'); ylabel('Y(m)'); zlabel('fi(%)'); 
rotate3d on
set(gcf,'Color',[1 1 1]);

% crtanje na ekvipotencijalnite linii
figure
[c, h] = contour(X,Y,fi,0:5:100); clabel(c, h); colorbar;
xlabel('X(m)'); ylabel('Y(m)');
set(gcf,'Color',[1 1 1]);