function fi = potencijal_tocka(T,I,L,rho)
% POTENCIJAL_TOCKA Presmetka na potencijal vo dadena tocka.
%
%   fi = potencijal_tocka(T,I,L,rho)
%
%   Vlez:
%       T : Vektor, redica, so trite koordinati na tockata.
%       I : Vektor so strui na odveduvanje od oddelnite sprovodnici na
%           zazemjuvacot.
%       L : Matrica so podatoci za sprovodnicite. Vo prvite 6 koloni se
%           dadeni x, y i z koordinatite na krajnite tocki od sekoj
%           sprovodnik (izrazeni vo m), a vo kolonata 7 e dijametarot na
%           sprovodnikot (izrazen vo mm).
%     rho : Specificna otpornost na tloto.
%
%   Izlez:
%      fi : Vrednost na presmetaniot potencijal.
%
%  See also ZAZEM.

fi = 0;
n = size(L,1);
for i = 1:n
    [P,Q] = deal(L(i,1:3),L(i,4:6));
     d = norm(P-Q);
    r1 = norm(P-T);
    r2 = norm(Q-T);
    fi = fi + rho*I(i)/(4*pi*d)*log((r1+r2+d)/(r1+r2-d));
end